@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.66 2004/06/09 23:50:56 dsmit Exp $ */
+/* $Id: gdict-app.c,v 1.67 2004/08/24 04:45:21 davyd Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -1005,6 +1005,8 @@ GtkWidget *gdict_app_create (gboolean applet) {
   
     gtk_widget_show (GTK_WIDGET (defbox));
     gtk_text_view_set_editable (GTK_TEXT_VIEW (defbox), FALSE);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+		    GTK_SHADOW_ETCHED_IN);
     gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (defbox));
 
     gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
