@@ -1,7 +1,7 @@
 #ifndef __GDICT_SPELLER_H_
 #define __GDICT_SPELLER_H_
 
-/* $Id: gdict-speller.h,v 1.3 2001/12/03 01:57:26 kevinv Exp $ */
+/* $Id: gdict-speller.h,v 1.5 2003/11/10 01:49:50 gman Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -40,8 +40,8 @@ struct _GDictSpeller {
     gchar          *database;
     gchar          *strat;
     
-    GtkTable       *table;
-    GtkEntry       *word_entry;
+    GtkWidget      *hbox;
+    GtkEntry       *word_entry;    
     GtkOptionMenu  *strat_sel;
     GtkMenu        *strat_list;
     guint           strat_idx;
@@ -61,7 +61,7 @@ struct _GDictSpellerClass {
 
 GType      gdict_speller_get_type    (void);
 
-GtkWidget *gdict_speller_new         (dict_context_t *context);
+GtkWidget *gdict_speller_new         ();
 void       gdict_speller_destroy     (GDictSpeller *speller);
 
 gint       gdict_speller_lookup      (GDictSpeller *speller, gchar *text);
