@@ -53,6 +53,8 @@
 #define ICON_THEME_SOCKET          "gnome-fs-socket"
 #define ICON_THEME_FIFO            "gnome-fs-fifo"
 #define MAX_SYMLINKS_FOLLOWED      32
+#define GSEARCH_DATE_FORMAT_LOCALE "locale"
+#define GSEARCH_DATE_FORMAT_ISO    "iso"
 
 
 /* START OF THE GCONF FUNCTIONS */
@@ -309,7 +311,8 @@ is_path_in_home_folder (const gchar *path)
 gboolean 
 is_path_in_mount_folder (const gchar *path)
 {
-	return (g_strstr_len (path, strlen ("/mnt/"), "/mnt/") != NULL);
+	return ((g_strstr_len (path, strlen ("/mnt/"), "/mnt/") != NULL) ||
+	        (g_strstr_len (path, strlen ("/media/"), "/media/") != NULL));
 }
 
 gboolean 
@@ -407,7 +410,7 @@ escape_single_quotes (const gchar *string)
 }
 
 gchar *
-backslash_backslashes (const gchar *string)
+backslash_special_characters (const gchar *string)
 {
 	GString *gs;
 
@@ -415,7 +418,8 @@ backslash_backslashes (const gchar *string)
 		return NULL;
 	}
 
-	if (count_of_char_in_string (string, '\\') == 0) {
+	if ((count_of_char_in_string (string, '\\') == 0) &&
+	    (count_of_char_in_string (string, '-') == 0)) {
 		return g_strdup(string);
 	}
 	gs = g_string_new ("");
@@ -423,6 +427,9 @@ backslash_backslashes (const gchar *string)
 		if (*string == '\\') {
 			g_string_append(gs, "\\\\");
 		}
+		else if (*string == '-') {
+			g_string_append(gs, "\\-");
+		}
 		else {
 			g_string_append_c(gs, *string);
 		}
@@ -473,6 +480,16 @@ get_readable_date (const time_t file_time_raw)
 	gchar *readable_date;
 
 	file_time = localtime (&file_time_raw);
+
+	/* Base format of date column on nautilus date_format key */
+	if (search_command.date_format_pref != NULL) {
+		if (strcmp(search_command.date_format_pref, GSEARCH_DATE_FORMAT_LOCALE) == 0) {
+			return gsearchtool_strdup_strftime ("%c", file_time);
+		} else if (strcmp (search_command.date_format_pref, GSEARCH_DATE_FORMAT_ISO) == 0) {
+			return gsearchtool_strdup_strftime ("%Y-%m-%d %H:%M:%S", file_time);
+		}
+	}
+	
 	file_date = g_date_new_dmy (file_time->tm_mday,
 			       file_time->tm_mon + 1,
 			       file_time->tm_year + 1900);
@@ -495,9 +512,9 @@ get_readable_date (const time_t file_time_raw)
 	} else if (file_date_age == 1) {
 		format = g_strdup(_("yesterday at %-I:%M %p"));
 	} else if (file_date_age < 7) {
-		format = g_strdup(_("%m/%-d/%y, %-I:%M %p"));
+		format = g_strdup(_("%A, %B %-d %Y at %-I:%M:%S %p"));
 	} else {
-		format = g_strdup(_("%m/%-d/%y, %-I:%M %p"));
+		format = g_strdup(_("%A, %B %-d %Y at %-I:%M:%S %p"));
 	}
 	
 	readable_date = gsearchtool_strdup_strftime (format, file_time);
@@ -714,7 +731,7 @@ get_file_pixbuf_for_mime_type (const gchar *filename,
 	if (pixbuf == NULL) {
 		pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon_name, 
 		                                   ICON_SIZE, 0, NULL);
-		g_hash_table_insert (search_command.pixbuf_hash, g_strdup (icon_name), pixbuf);
+		g_hash_table_insert (search_command.pixbuf_hash, &icon_name, pixbuf);
 	}
 						  
 	g_free (icon_name);
