@@ -30,6 +30,7 @@
 #include <sys/stat.h>
 #include "logview.h"
 #include <libgnomeui/gnome-window-icon.h>
+#include <ctype.h>
 
 /*
  *    -------------------
@@ -64,6 +65,8 @@ int read_actions_db (char *filename, GList **db);
 void print_db (GList *gb);
 Log *OpenLogFile (char *);
 void SaveUserPrefs(UserPrefsStruct *prefs);
+char * parse_syslog(gchar * syslog_file);
+
 void close_zoom_view (GtkWidget *widget, gpointer client_data);
 void handle_selection_changed_cb (GtkTreeSelection *selection, gpointer data);
 void handle_row_activation_cb (GtkTreeView *treeview, GtkTreePath *path, 
@@ -876,8 +879,13 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 		g_free (logfile);
 	}
 	else {
-		/* First time running logview. Try to find the logfile */
-		if (lstat("/var/adm/messages", &filestat) == 0) 
+
+		/* For first time running, try parsing /etc/syslog.conf */
+		if (lstat("/etc/syslog.conf", &filestat) == 0) {
+			if ((logfile = parse_syslog("/etc/syslog.conf")) == NULL);
+			prefs->logfile = g_strdup (logfile);
+		}
+		else if (lstat("/var/adm/messages", &filestat) == 0) 
 			prefs->logfile = g_strdup ("/var/adm/messages");
 		else if (lstat("/var/log/messages", &filestat) == 0) 
 			prefs->logfile = g_strdup ("/var/log/messages");
@@ -888,6 +896,59 @@ void SetDefaultUserPrefs(UserPrefsStruct *prefs)
 	}
 }
 
+char * parse_syslog(gchar * syslog_file) {
+/* Most of this stolen from sysklogd sources */
+    char * logfile = NULL;
+    char cbuf[BUFSIZ];
+    char *cline;
+    char *p;
+    FILE * cf;
+    if ((cf = fopen(syslog_file, "r")) == NULL) {
+        fprintf(stderr, "Could not open file: (%s)\n", syslog_file);
+        return NULL;
+    }
+    cline = cbuf;
+    while (fgets(cline, sizeof(cbuf) - (cline - cbuf), cf) != NULL) {
+        for (p = cline; isspace(*p); ++p);
+        if (*p == '\0' || *p == '#')
+            continue;
+        for (;*p && !strchr("\t ", *p); ++p);
+        while (*p == '\t' || *p == ' ')
+            p++;
+        if (*p == '-')
+            p++;
+        if (*p == '/') {
+            logfile = g_strdup (p);
+            /* remove trailing newline */
+            if (logfile[strlen(logfile)-1] == '\n')
+                logfile[strlen(logfile)-1] = '\0';
+            fprintf(stderr, "Found a logfile: (%s)\n", logfile);
+            return logfile;
+        }
+        /* I don't totally understand this code
+           it came from syslogd.c and is supposed
+           to read run-on lines that end with \
+           FIXME?? */
+        /*
+        if (*p == '\\') {
+            if ((p - cbuf) > BUFSIZ - 30) {
+                cline = cbuf;
+            } else {
+                *p = 0;
+                cline = p;
+                continue;
+            }
+        }  else
+            cline = cbuf;
+        *++p = '\0';
+        */
+        
+    }
+    return logfile; 
+}
+
+
+ 
 void SaveUserPrefs(UserPrefsStruct *prefs)
 {
     if (gconf_client_key_is_writable (client, "/apps/logview/logfile", NULL) &&
